@@ -24,7 +24,7 @@ setMethod ("coltab<-" , "SpatRaster",
 		layer <- layer[1]-1
 		
 		if (is.null(value)) {
-			x@ptr$removeColors(layer-1)
+			x@ptr$removeColors(layer)
 			return(x)
 		}
 
