@@ -198,26 +198,24 @@ setMethod("buffer", signature(x="SpatVector"),
 
 setMethod("crop", signature(x="SpatVector", y="ANY"), 
 	function(x, y) {
-		if (!inherits(y, "SpatExtent")) {
-			y <- try(ext(y), silent=TRUE)
-			if (inherits(y, "try-error")) {
-				stop("y does not have a SpatExtent")
+		if (inherits(y, "SpatVector")) {
+			if (length(y) > 1) {
+				y <- aggregate(y)
 			}
+			x@ptr <- x@ptr$crop_vct(y@ptr)
+		} else {
+			if (!inherits(y, "SpatExtent")) {
+				y <- try(ext(y), silent=TRUE)
+				if (inherits(y, "try-error")) {
+					stop("y does not have a SpatExtent")
+				}
+			}
+			x@ptr <- x@ptr$crop_ext(y@ptr)
 		}
-		x@ptr <- x@ptr$crop_ext(y@ptr)
 		messages(x, "crop")
 	}
 )
 
-setMethod("crop", signature(x="SpatVector", y="SpatVector"), 
-	function(x, y) {
-		if (length(y) > 1) {
-			y <- aggregate(y)
-		}
-		x@ptr <- x@ptr$crop_vct(y@ptr)
-		messages(x, "crop")
-	}
-)
 
 setMethod("convHull", signature(x="SpatVector"), 
 	function(x, by="") {
@@ -229,15 +227,15 @@ setMethod("convHull", signature(x="SpatVector"),
 setMethod("minRect", signature(x="SpatVector"), 
 	function(x, by="") {
 		x@ptr <- x@ptr$hull("minrot", by[1])
-		messages(x, "convHull")
+		messages(x, "minRect")
 	}
 )
 
 
-setMethod("disaggregate", signature(x="SpatVector"), 
+setMethod("disagg", signature(x="SpatVector"), 
 	function(x) {
 		x@ptr <- x@ptr$disaggregate()
-		messages(x, "disaggregate")
+		messages(x, "disagg")
 	}
 )
 
