@@ -6,7 +6,7 @@
 #)
 
 setMethod("vect", signature(x="missing"), 
-	function(...) {
+	function(x) {
 		p <- methods::new("SpatVector")
 		p@ptr <- SpatVector$new()
 		messages(p, "vect")
@@ -15,21 +15,31 @@ setMethod("vect", signature(x="missing"),
 )
 
 setMethod("vect", signature(x="character"), 
-	function(x, ...) {
+	function(x, layer="", query="", extent=NULL, filter=NULL, crs="") {
 		p <- methods::new("SpatVector")
 		s <- substr(x[1], 1, 5)
 		if (s %in% c("POINT", "MULTI", "LINES", "POLYG")) {
 #		if (all(grepl("\\(", x) & grepl("\\)", x))) {
 			x <- gsub("\n", "", x)
 			p@ptr <- SpatVector$new(x)
-			dots <- list(...)
-			if (!is.null(dots$crs)) {
-				crs(p) <- dots$crs
-			}
+			crs(p) <- crs
 		} else {
 			p@ptr <- SpatVector$new()
 			x <- normalizePath(x)
-			p@ptr$read(x)
+			if (is.null(filter)) {
+				filter <- vect()@ptr
+			} else {
+				filter <- filter@ptr
+			}
+			if (is.null(extent)) {
+				extent <- double()
+			} else {
+				extent <- as.vector(ext(extent))
+			}
+			p@ptr$read(x, layer, query, extent, filter)
+			if (isTRUE(crs != "")) {
+				crs(p) <- crs
+			}
 		}
 		messages(p, "vect")
 	}
@@ -87,7 +97,7 @@ setMethod("vect", signature(x="XY"), #sfg
 }
 
 setMethod("vect", signature(x="matrix"), 
-	function(x, type="points", atts=NULL, crs="", ...) {
+	function(x, type="points", atts=NULL, crs="") {
 		type <- tolower(type)
 		type <- match.arg(tolower(type), c("points", "lines", "polygons"))
 		stopifnot(NCOL(x) > 1)
@@ -147,6 +157,49 @@ function(x, i, j, ... ,drop=FALSE) {
 
 
 
+setReplaceMethod("[", c("SpatVector", "ANY", "ANY"),
+	function(x, i, j, value) {
+		v <- values(x)
+		v[i,j] <- value
+		if (nrow(v) != nrow(x)) {
+			error("[<-", "this would create an invalid SpatVector")
+		}
+		values(x) <- v
+		x
+	}
+)
+
+setReplaceMethod("[", c("SpatVector", "ANY", "missing"),
+	function(x, i, j, value) {
+		v <- values(x)
+		if (inherits(value, "SpatVector")) {
+			value <- values(value)
+		}
+		v[i,] <- value
+		if (nrow(v) != nrow(x)) {
+			error("[<-", "this would create an invalid SpatVector")
+		}
+		values(x) <- v
+		x
+	}
+)
+
+setReplaceMethod("[", c("SpatVector", "missing", "ANY"),
+	function(x, i, j, value) {
+		v <- values(x)
+		if (inherits(value, "SpatVector")) {
+			value <- values(value)
+		}
+		v[,j] <- value
+		if (nrow(v) != nrow(x)) {
+			error("[<-", "this would create an invalid SpatVector")
+		}
+		values(x) <- v
+		x
+	}
+)
+
+
 setReplaceMethod("[[", c("SpatVector", "character", "missing"),
 	function(x, i, j, value) {
 		
@@ -206,13 +259,19 @@ setMethod("$<-", "SpatVector",
 
 
 setMethod("vect", signature(x="data.frame"), 
-	function(x, geom=c("lon", "lat"), crs=NA, ...) {
+	function(x, geom=c("lon", "lat"), crs=NA) {
+		if (!all(geom %in% names(x))) {
+			error("vect", "the variable name(s) in argument `geom` are not in `x`")
+		}
 		if (length(geom) == 2) {
 			v <- vect(as.matrix(x[,geom]), crs=crs)
 		} else if (length(geom) == 1) {
 			v <- vect(unlist(x[,geom]), crs=crs)
+		} else {
+			error("vect", "the length of 'geom' must be 1 or 2")
 		}
 		values(v) <- x
 		v
 	}
 )
+
